use strict;
use warnings;

package URT;

use UR;

class URT {
    is => ['UR::Namespace'],
    type_name => 'urt',
    doc => 'A dummy namespace used by the UR test suite.',
};

1;
#$Header
